@@ -292,4 +292,37 @@ def linearRegressionPerProduct(file,product_number):
     print('Root Mean Squared Error:', np.sqrt(metrics.mean_squared_error(y_test, y_pred)))
     plt.scatter(X_test, y_test,  color='gray')
     plt.plot(X_test, y_pred, color='red', linewidth=2)
-    plt.show()
\ No newline at end of file
+    plt.show()
+    
+def eoqPerProduct(file,product_number,setupCost,holdingCost):
+    sales = pd.read_csv(file)
+    sales['ref'] = sales['ref'].astype('category')
+    sales['date'] = pd.to_datetime(sales['date'],  errors='coerce')
+    sales['product_number'] = sales['product_number'].astype('category')
+    sales['product_name'] = sales['product_name'].astype('category')
+    sales = sales.loc[sales['product_number'] == product_number]
+    sales_qty = sales[['date','quantity']]
+    sales_qty = sales_qty.set_index(["date"])
+    sales_qty = sales_qty.resample('Y').sum()
+    avg_qty = sales_qty.quantity.mean()
+    EOQ = math.sqrt(2*avg_qty*setupCost/holdingCost)
+    print('EOQ :', EOQ)
+    
+def avgQtySoldList(file):
+    sales = pd.read_csv(file)
+    sales['ref'] = sales['ref'].astype('category')
+    sales['date'] = pd.to_datetime(sales['date'],  errors='coerce')
+    sales['product_number'] = sales['product_number'].astype('category')
+    sales['product_name'] = sales['product_name'].astype('category')
+    sales = sales.dropna()
+    pd.set_option('display.float_format', lambda x: '%.2f' % x)
+    result = pd.DataFrame(columns=['product_number', 'product_name', 'QTY Sold by Year'])
+    for pnum in sales.product_number.unique():
+        sales_prep = sales.loc[sales['product_number'] == pnum]
+        sales_qty = sales_prep[['date','quantity']]
+        sales_qty = sales_qty.set_index(["date"])
+        sales_qty = sales_qty.resample('Y').sum()
+        avg_qty = sales_qty.quantity.mean()
+        result = result.append({'product_number': pnum, 'product_name': sales_prep['product_name'].iloc[0], 'QTY Sold by Year': avg_qty}, ignore_index=True)
+    result.to_csv('avgQtySoldList.csv', index = False)
+    print("Average Quantity Sold Per Year", result, sep='\n')
\ No newline at end of file
